@@ -211,11 +211,12 @@ def get_block_windows(window_size, raster_x_size, raster_y_size):
         raster_y_size -= (raster_y_size % window_size)
 
     for y in range(0, raster_y_size, window_size):
-        ysize = min(window_size, raster_y_size - y)
+        # ysize = min(window_size, raster_y_size - y)
         for x in range(0, raster_x_size, window_size):
-            xsize = min(window_size, raster_x_size - x)
+            # xsize = min(window_size, raster_x_size - x)
 
-            yield x, y, xsize, ysize
+            # yield x, y, xsize, ysize
+            yield x, y, window_size, window_size
 
 
 @jit(nopython=True, nogil=True)
