@@ -101,6 +101,7 @@ class FotoBase:
     _keep_dc_component = None
     _method = None
     _out_dir = None
+    _nb_sampled_frequencies = None
     _normalized = None
     _standardized = None
     _window_size = None
@@ -110,7 +111,6 @@ class FotoBase:
     max_nb_sampled_frequencies = MAX_NB_OF_SAMPLED_FREQUENCIES
     nb_pca_components = NB_PCA_COMPONENTS
     no_data_value = R_SPECTRA_NO_DATA_VALUE
-    nb_sampled_frequencies = None
     eigen_vectors = None
 
     r_spectra_axis = _ISOTROPIC_R_SPECTRA_AXIS
@@ -132,7 +132,8 @@ class FotoBase:
     def _plot(self, root, window_size, reduced_r_spectra,
               method, nb_points, data_range, nb_quadrants,
               norm_method, nb_windows_per_side,
-              main_fig_rel_size, contrast_range, *args, **kwargs):
+              main_fig_rel_size, contrast_range, invert_axis,
+              *args, **kwargs):
         pass
 
     def compute_pca(self, standardized=True, at_random=False,
@@ -185,6 +186,7 @@ class FotoBase:
             step used in sliding window if method is "moving_window"
         nb_sampled_frequencies: int
             number of sampled frequencies (optional)
+            If None, is inferred from window size
         normalized: bool
             if True, divide by window variance
         keep_dc_component: bool
@@ -205,7 +207,7 @@ class FotoBase:
         self.keep_dc_component = keep_dc_component
 
         if not nb_sampled_frequencies:
-            self.nb_sampled_frequencies = min(max(int(window_size / 2), 3),
+            self.nb_sampled_frequencies = min(int(window_size / 2),
                                               self.max_nb_sampled_frequencies)
         else:
             self.nb_sampled_frequencies = nb_sampled_frequencies
@@ -256,7 +258,8 @@ class FotoBase:
 
     def plot(self, h5path=None, nb_points=10000, data_range=None,
              nb_quadrants=12, norm_method="max", nb_windows_per_side=2,
-             main_fig_rel_size=0.6, contrast_range=(2, 98), *args, **kwargs):
+             main_fig_rel_size=0.6, contrast_range=(2, 98), invert_axis=False,
+             *args, **kwargs):
         """ Plot factorial plan and corresponding windows for each quadrant
 
         Parameters
@@ -287,6 +290,8 @@ class FotoBase:
             windows with respect to the whole image.
             ex.: enhance contrast based on cumulative
             count cut between 2% and 98% --> [2, 98]
+        invert_axis: bool
+            if True, set PCA 1 on y axis / PCA 2 on x axis
 
         Returns
         -------
@@ -310,7 +315,7 @@ class FotoBase:
         # Call plot protected method
         self._plot(root, window_size, reduced_r_spectra, method, nb_points, data_range,
                    nb_quadrants, norm_method, nb_windows_per_side, main_fig_rel_size,
-                   contrast_range, *args, **kwargs)
+                   contrast_range, invert_axis, *args, **kwargs)
 
         tk.mainloop()
 
@@ -486,15 +491,10 @@ class FotoBase:
 
     @property
     def path(self):
-        if self.method == "block":
-            return os.path.join(self.out_dir, f"{self.__class__.__name__.upper()}_method"
-                                              f"={self.method}_wsize={self.window_size}_"
-                                              f"dc={self.keep_dc_component}_")
-        else:
-            return os.path.join(self.out_dir, f"{self.__class__.__name__.upper()}_method"
-                                              f"={self.method}_wsize="
-                                              f"{self.window_size}_wstep={self.window_step}_"
-                                              f"dc={self.keep_dc_component}_")
+        return os.path.join(self.out_dir, f"{self.__class__.__name__.upper()}_method"
+                                          f"={self.method}_wsize="
+                                          f"{self.window_size}_wstep={self.window_step}_"
+                                          f"dc={self.keep_dc_component}_normalized={self.normalized}_")
 
     @property
     def mean(self):
@@ -503,6 +503,19 @@ class FotoBase:
         else:
             return self.h5[R_SPECTRA_H5_DS_NAME].attrs['mean']
 
+    @property
+    def nb_sampled_frequencies(self):
+        return self._nb_sampled_frequencies
+
+    @nb_sampled_frequencies.setter
+    @integer
+    @positive
+    def nb_sampled_frequencies(self, value):
+        if value < self.nb_pca_components:
+            raise ValueError("You cannot sample less frequencies than PCA components ! "
+                             "(you may want to check window size)")
+        self._nb_sampled_frequencies = value
+
     @property
     def normalized(self):
         return self._normalized
