@@ -9,7 +9,10 @@ import multiprocessing as mp
 import os
 from abc import abstractmethod
 
-import gdal
+try:
+    import gdal
+except ModuleNotFoundError:
+    from osgeo import gdal
 
 from fototex.base import FotoBase, Batch, Sector
 from fototex.plotting import plot
@@ -77,11 +80,13 @@ class Foto(FotoBase):
     def _plot(self, root, window_size, reduced_r_spectra,
               method, nb_points, data_range, nb_quadrants,
               norm_method, nb_windows_per_side,
-              main_fig_rel_size, contrast_range, *args, **kwargs):
+              main_fig_rel_size, contrast_range, invert_axis,
+              *args, **kwargs):
 
         plot(root, self, window_size, reduced_r_spectra, method,
              nb_points, data_range, nb_quadrants, norm_method,
-             main_fig_rel_size, nb_windows_per_side, contrast_range)
+             main_fig_rel_size, nb_windows_per_side, contrast_range,
+             invert_axis)
 
     def get_window_generator(self):
         """ Create window generator depending on the given memory method
@@ -207,11 +212,12 @@ class FotoBatch(Batch):
     def _plot(self, root, window_size, reduced_r_spectra,
               method, nb_points, data_range, nb_quadrants,
               norm_method, nb_windows_per_side,
-              main_fig_rel_size, contrast_range, *args, **kwargs):
+              main_fig_rel_size, contrast_range, invert_axis,
+              *args, **kwargs):
 
         plot(root, self.foto_instances, window_size, reduced_r_spectra, method,
              nb_points, data_range, nb_quadrants, norm_method, main_fig_rel_size,
-             nb_windows_per_side, contrast_range)
+             nb_windows_per_side, contrast_range, invert_axis)
 
     def compute_r_spectra(self, window_size, window_step=1, nb_sampled_frequencies=None,
                           normalized=False, keep_dc_component=False, nb_processes=mp.cpu_count(),
